@@ -5,6 +5,7 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
+from tkdev.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevAudio
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
     Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
@@ -1565,5 +1566,6 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
-    DevTooltip(Window, Window, cursor=True, width=100)
+    Notification = DevNotification()
+    Notification.show()
     Window.mainloop()
