@@ -63,10 +63,13 @@ def download_winico():
 
             def Get_Data():
                 if Is64Windows():
+                    print("检测到是64位系统，将会安装64版本的winico")
                     Url = "https://tkdev-docs.netlify.app/_files/Winico64.zip"
                 elif not Is64Windows():
+                    print("检测到是32位系统，将会安装64版本的winico")
                     Url = "https://tkdev-docs.netlify.app/_files/Winico32.zip"
                 else:
+                    print("未检测到版本，将会安装64版本的winico")
                     Url = "https://tkdev-docs.netlify.app/_files/Winico64.zip"
                 Response = requests.get(Url)
                 return Url, Response.content
